@@ -22,6 +22,10 @@ COLUMN_MODIFIER_DESCR = _(
     u'the chosen column modifier of LibreOffice will be applied.')
 
 
+def _string_to_boolean(value):
+    return value == "True"
+
+
 def check_for_uno(value):
     """
     """
@@ -82,12 +86,13 @@ class IDocumentGeneratorControlPanelSchema(Interface):
         default=False
     )
 
-    use_stream = schema.Bool(
+    use_stream = schema.Choice(
         title=_(u'Force communication via in/out stream with LibreOffice.'),
         description=_(u'If enabled, this will force using stream to communicate witth LibreOffice server. '
                       u'This must be true if the LO server is not on localhost or is in a docker container.'),
         required=True,
-        default=bool(os.getenv('USE_STREAM', False) == 'True'),
+        vocabulary='collective.documentgenerator.ConfigStream',
+        default=os.getenv('USE_STREAM', None) is None and 'auto' or _string_to_boolean(os.getenv('USE_STREAM')),
     )
 
 
@@ -95,7 +100,7 @@ class IDocumentGeneratorControlPanelSchema(Interface):
 class DocumentGeneratorControlPanelEditForm(RegistryEditForm):
     schema = IDocumentGeneratorControlPanelSchema
     label = _(u'Document Generator settings')
-    description = _(u'')
+    description = _(u'The Document Generator settings control panel')
 
     @button.buttonAndHandler(_('Save'), name=None)
     def handle_save(self, action):
